aperture - Telescope Pupil Generators
=====================================

.. currentmodule:: hcipy.aperture

.. automodapi:: hcipy.aperture
    :no-inheritance-diagram:
    :include-all-objects:
    :no-heading: